Usage
ggslackr(plot = last_plot(), channels = Sys.getenv("SLACK_CHANNEL"),
scale = 1, width = par("din")[1], height = par("din")[2],
units = c("in", "cm", "mm"), dpi = 300, limitsize = TRUE,
api_token = Sys.getenv("SLACK_API_TOKEN"), ...)Arguments
plot
ggplot object to save, defaults to last plot displayed
channels
list of channels to post image to
width
width (defaults to the width of current plotting window)
height
height (defaults to the height of current plotting window)
units
units for width and height when either one is explicitly specified (in, cm, or mm)
dpi
dpi to use for raster graphics
limitsize
when TRUE (the default), ggsave will not save images larger than 50x50 inches, to prevent the common error of specifying dimensions in pixels.
api_token
the slack.com full API token (chr)
...
other arguments passed to graphics device